@@ -17,8 +17,9 @@
  * along with Bowtie 2.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mutex>
+
 #include "aligner_cache.h"
-#include "tinythread.h"
 
 #ifndef NDEBUG
 /**
@@ -98,8 +99,8 @@ bool AlignmentCache::addOnTheFlyImpl(
 	}
 	// Now that we know all allocations have succeeded, we can do a few final
 	// updates
-	
-	return true; 
+
+	return true;
 }
 
 bool AlignmentCache::addOnTheFly(
