@@ -20,13 +20,9 @@
 #ifndef DIFF_SAMPLE_H_
 #define DIFF_SAMPLE_H_
 
-#ifdef WITH_TBB
-#include <tbb/tbb.h>
-#include <tbb/task_group.h>
-#endif
-
 #include <stdint.h>
 #include <string.h>
+#include <thread>
 #include "assert_helpers.h"
 #include "multikey_qsort.h"
 #include "timer.h"
@@ -697,7 +693,6 @@ struct VSortingParam {
 };
 
 template<typename TStr>
-#ifdef WITH_TBB
 class VSorting_worker {
         void *vp;
 
@@ -706,45 +701,39 @@ public:
 	VSorting_worker(const VSorting_worker& W): vp(W.vp) {};
 	VSorting_worker(void *vp_):vp(vp_) {};
 	void operator()() const
-	{
-#else
-static void VSorting_worker(void *vp)
-{
-#endif
-    VSortingParam<TStr>* param = (VSortingParam<TStr>*)vp;
-    DifferenceCoverSample<TStr>* dcs = param->dcs;
-    const TStr& host = dcs->text();
-    const size_t hlen = host.length();
-    uint32_t v = dcs->v();
-    while(true) {
-        size_t cur = 0;
-        {
-            ThreadSafe ts(*param->mutex);
-            cur = *(param->cur);
-            (*param->cur)++;
-        }
-        if(cur >= param->boundaries->size()) return;
-        size_t begin = (cur == 0 ? 0 : (*param->boundaries)[cur-1]);
-        size_t end = (*param->boundaries)[cur];
-        assert_leq(begin, end);
-        if(end - begin <= 1) continue;
-        mkeyQSortSuf2(
-                      host,
-                      hlen,
-                      param->sPrimeArr,
-                      param->sPrimeSz,
-                      param->sPrimeOrderArr,
-                      4,
-                      begin,
-                      end,
-                      param->depth,
-                      v);
-    }
-}
+		{
+			VSortingParam<TStr>* param = (VSortingParam<TStr>*)vp;
+			DifferenceCoverSample<TStr>* dcs = param->dcs;
+			const TStr& host = dcs->text();
+			const size_t hlen = host.length();
+			uint32_t v = dcs->v();
+			while(true) {
+				size_t cur = 0;
+				{
+					ThreadSafe ts(*param->mutex);
+					cur = *(param->cur);
+					(*param->cur)++;
+				}
+				if(cur >= param->boundaries->size()) return;
+				size_t begin = (cur == 0 ? 0 : (*param->boundaries)[cur-1]);
+				size_t end = (*param->boundaries)[cur];
+				assert_leq(begin, end);
+				if(end - begin <= 1) continue;
+				mkeyQSortSuf2(
+					host,
+					hlen,
+					param->sPrimeArr,
+					param->sPrimeSz,
+					param->sPrimeOrderArr,
+					4,
+					begin,
+					end,
+					param->depth,
+					v);
+			}
+		}
 
-#ifdef WITH_TBB
 };
-#endif
 
 /**
  * Calculates a ranking of all suffixes in the sample and stores them,
@@ -817,11 +806,7 @@ void DifferenceCoverSample<TStr>::build(int nthreads) {
 				mkeyQSortSuf2(t, sPrimeArr, sPrimeSz, sPrimeOrderArr, 4,
 				              this->verbose(), false, query_depth, &boundaries);
 				if(boundaries.size() > 0) {
-#ifdef WITH_TBB
-					tbb::task_group tbb_grp;
-#else
-					AutoArray<tthread::thread*> threads(nthreads);
-#endif
+					AutoArray<std::thread*> threads(nthreads);
 					EList<VSortingParam<TStr> > tparams;
 					size_t cur = 0;
 					MUTEX_T mutex;
@@ -837,17 +822,13 @@ void DifferenceCoverSample<TStr>::build(int nthreads) {
 						tparams[tid].boundaries = &boundaries;
 						tparams[tid].cur = &cur;
 						tparams[tid].mutex = &mutex;
-#ifdef WITH_TBB
-						tbb_grp.run(VSorting_worker<TStr>(((void*)&tparams[tid])));
-					}
-					tbb_grp.wait();
-#else
-						threads[tid] = new tthread::thread(VSorting_worker<TStr>, (void*)&tparams[tid]);
+						threads[tid] = new std::thread(VSorting_worker<TStr>(((void*)&tparams[tid])));
 					}
 					for (int tid = 0; tid < nthreads; tid++) {
 						threads[tid]->join();
 					}
-#endif
+					for (int tid = 0; tid < nthreads; tid++)
+						delete threads[tid];
 				}
 				if(this->sanityCheck()) {
 					sanityCheckOrderedSufs(t, t.length(), sPrimeArr, sPrimeSz, v);
