@@ -31,6 +31,9 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <zlib.h>
+#ifdef WITH_ZSTD
+#include "zstd_decompress.h"
+#endif
 
 /**
  * Simple, fast helper for determining if a character is a newline.
@@ -74,6 +77,13 @@ public:
 		_zIn = in;
 		assert(_zIn != NULL);
 	}
+#ifdef WITH_ZSTD
+	FileBuf(zstdStrm *zstdIn) {
+		init();
+		_zstdIn = zstdIn;
+		assert(_zstdIn != NULL);
+	}
+#endif
 
 	FileBuf(std::ifstream *inf) {
 		init();
@@ -109,6 +119,10 @@ public:
 			_inf->close();
 		} else if(_zIn != NULL) {
 			gzclose(_zIn);
+#ifdef WITH_ZSTD
+		} else if(_zstdIn != NULL) {
+			zstdClose(_zstdIn);
+#endif
 		} else {
 			// can't close _ins
 		}
@@ -119,6 +133,9 @@ public:
 	 */
 	int get() {
 		assert(_in != NULL || _zIn != NULL || _inf != NULL || _ins != NULL);
+#ifdef WITH_ZSTD
+		assert(zstdIn != NULL)
+#endif
 		int c = peek();
 		if(c != -1) {
 			_cur++;
@@ -142,6 +159,9 @@ public:
 		_zIn = NULL;
 		_inf = NULL;
 		_ins = NULL;
+#ifdef WITH_ZSTD
+		_zstdIn = NULL;
+#endif
 		_cur = BUF_SZ;
 		_buf_sz = BUF_SZ;
 		_done = false;
@@ -155,11 +175,29 @@ public:
 		_zIn = in;
 		_inf = NULL;
 		_ins = NULL;
+#ifdef WITH_ZSTD
+		_zstdIn = NULL;
+#endif
 		_cur = BUF_SZ;
 		_buf_sz = BUF_SZ;
 		_done = false;
 	}
 
+#ifdef WITH_ZSTD
+	/**
+	 * Initialize the buffer with a new ZSTD file.
+	 */
+	void newFile(zstdStrm *s) {
+		_in = NULL;
+		_zIn = NULL;
+		_inf = NULL;
+		_ins = NULL;
+		_zstdIn = s;
+		_cur = BUF_SZ;
+		_buf_sz = BUF_SZ;
+		_done = false;
+	}
+#endif
 	/**
 	 * Initialize the buffer with a new ifstream.
 	 */
@@ -168,6 +206,9 @@ public:
 		_zIn = NULL;
 		_inf = __inf;
 		_ins = NULL;
+#ifdef WITH_ZSTD
+		_zstdIn = NULL;
+#endif
 		_cur = BUF_SZ;
 		_buf_sz = BUF_SZ;
 		_done = false;
@@ -181,6 +222,9 @@ public:
 		_zIn = NULL;
 		_inf = NULL;
 		_ins = __ins;
+#ifdef WITH_ZSTD
+		_zstdIn = NULL;
+#endif
 		_cur = BUF_SZ;
 		_buf_sz = BUF_SZ;
 		_done = false;
@@ -199,6 +243,10 @@ public:
 			_ins->seekg(0, std::ios::beg);
 		} else if (_zIn != NULL) {
 			gzrewind(_zIn);
+#ifdef WITH_ZSTD
+		} else if (_zstdIn) {
+			zstdRewind(_zstdIn);
+#endif
 		} else {
 			rewind(_in);
 		}
@@ -214,6 +262,9 @@ public:
 	 */
 	int peek() {
 		assert(_in != NULL || _zIn != NULL || _inf != NULL || _ins != NULL);
+#ifdef WITH_ZSTD
+		assert(zstdIn != NULL);
+#endif
 		assert_leq(_cur, _buf_sz);
 		if(_cur == _buf_sz) {
 			if(_done) {
@@ -231,12 +282,16 @@ public:
 				} else if(_ins != NULL) {
 					_ins->read((char*)_buf, BUF_SZ);
 					_buf_sz = _ins->gcount();
-				} else {
+#ifdef WITH_ZSTD
+                                } else if (_zstdIn != NULL) {
+					_buf_sz = zstdRead(_zstdIn, (void *)_buf, BUF_SZ);
+#endif
+                                } else {
 					assert(_in != NULL);
 					// TODO: consider an _unlocked function
 					_buf_sz = fread(_buf, 1, BUF_SZ, _in);
-				}
-				_cur = 0;
+                                }
+                                _cur = 0;
 				if(_buf_sz == 0) {
 					// Exhausted, and we have nothing to return to the
 					// caller
@@ -470,6 +525,9 @@ private:
 		_zIn = NULL;
 		_inf = NULL;
 		_ins = NULL;
+#ifdef WITH_ZSTD
+		_zstdIn = NULL;
+#endif
 		_cur = _buf_sz = BUF_SZ;
 		_done = false;
 		_lastn_cur = 0;
@@ -479,6 +537,9 @@ private:
 	static const size_t BUF_SZ = 256 * 1024;
 	FILE     *_in;
 	gzFile   _zIn;
+#ifdef WITH_ZSTD
+	zstdStrm *_zstdIn;
+#endif
 	std::ifstream *_inf;
 	std::istream  *_ins;
 	size_t    _cur;
