@@ -33,6 +33,7 @@
 #include "util.h"
 #include "str_util.h"
 #include "tokenize.h"
+#include "endian_swap.h"
 
 using namespace std;
 
@@ -461,19 +462,26 @@ pair<bool, int> CFilePatternSource::nextBatch(
 void CFilePatternSource::open() {
 	if(is_open_) {
 		is_open_ = false;
-		if (compressed_) {
+		switch (compressionType_) {
+		case CompressionType::GZIP:
 			gzclose(zfp_);
 			zfp_ = NULL;
-		}
-		else {
+			break;
+#ifdef WITH_ZSTD
+		case CompressionType::ZSTD:
+			zstdClose(zstdfp_);
+			zstdfp_ = NULL;
+			break;
+#endif
+		case CompressionType::NONE:
 			fclose(fp_);
-      			fp_ = NULL;
-      		}
+			fp_ = NULL;
+		}
 	}
 	while(filecur_ < infiles_.size()) {
 		if(infiles_[filecur_] == "-") {
 			// always assume that data from stdin is compressed
-			compressed_ = true;
+			compressionType_ = CompressionType::GZIP;
 			int fd = dup(fileno(stdin));
 			zfp_ = gzdopen(fd, "rb");
 
@@ -495,14 +503,29 @@ void CFilePatternSource::open() {
 
 			is_fifo = S_ISFIFO(st.st_mode) != 0;
 #endif
-			if (pp_.format != BAM && (is_fifo || is_gzipped_file(fd))) {
-				zfp_ = gzdopen(fd, "r");
-				compressed_ = true;
-			} else {
-				fp_ = fdopen(fd, "rb");
-			}
+#define CHECK_ERROR(exp) ((exp) == NULL) ? true : false
 
-			if((compressed_ && zfp_ == NULL) || (!compressed_ && fp_ == NULL)) {
+			bool err = false;
+                        if (pp_.format == BAM) {
+				err = CHECK_ERROR(fp_ = fdopen(fd, "rb"));
+				compressionType_ = CompressionType::NONE;
+                        } else if (is_fifo) {
+				err = CHECK_ERROR(zfp_ = gzdopen(fd, "rb"));
+				compressionType_ = CompressionType::GZIP;
+                        } else if (is_gzipped_file(fd)) {
+				err = CHECK_ERROR(zfp_ = gzdopen(fd, "rb"));
+				compressionType_ = CompressionType::GZIP;
+#ifdef WITH_ZSTD
+                        } else if (is_zstd_file(fd)) {
+				err = CHECK_ERROR(zstdfp_ = zstdFdOpen(fd));
+				compressionType_ = CompressionType::ZSTD;
+#endif
+                        } else {
+				err = CHECK_ERROR(fp_ = fdopen(fd, "r"));
+				compressionType_ = CompressionType::NONE;
+                        }
+
+			if(err) {
 				if (fd != -1) {
 					close(fd);
 				}
@@ -514,11 +537,12 @@ void CFilePatternSource::open() {
 					errs_[filecur_] = true;
 				}
 				filecur_++;
+				compressionType_ = CompressionType::NONE;
 				continue;
 			}
 		}
 		is_open_ = true;
-		if (compressed_) {
+		if (compressionType_ == CompressionType::GZIP) {
 #if ZLIB_VERNUM < 0x1235
 			cerr << "Warning: gzbuffer added in zlib v1.2.3.5. Unable to change "
 				"buffer size from default of 8192." << endl;
@@ -526,7 +550,7 @@ void CFilePatternSource::open() {
 			gzbuffer(zfp_, 128*1024);
 #endif
 		}
-		else {
+		else if (compressionType_ == CompressionType::NONE) {
 			setvbuf(fp_, buf_, _IOFBF, 64*1024);
 		}
 		return;
@@ -1197,6 +1221,10 @@ uint16_t BAMPatternSource::nextBGZFBlockFromFile(BGZF& b) {
                 std::cerr << "Error while reading BAM header" << std::endl;
                 exit(EXIT_FAILURE);
         }
+	if (currentlyBigEndian()) {
+		b.hdr.mtime = endianSwapU32(b.hdr.mtime);
+		b.hdr.xlen  = endianSwapU16(b.hdr.xlen);
+	}
 	uint8_t *extra = new uint8_t[b.hdr.xlen];
         if (fread(extra, b.hdr.xlen, 1, fp_) != 1) {
                 std::cerr << "Error while reading BAM extra subfields" << std::endl;
@@ -1212,11 +1240,15 @@ uint16_t BAMPatternSource::nextBGZFBlockFromFile(BGZF& b) {
 	for (uint16_t i = 0; i < b.hdr.xlen;) {
 		if (extra[0] == 66 && extra[1] == 67) {
 			bsize = *((uint16_t *)(extra + 4));
+			if (currentlyBigEndian())
+				bsize = endianSwapU16(bsize);
 			bsize -= (b.hdr.xlen + 19);
 			break;
 		}
 		i = i + 2;
 		uint16_t sub_field_len = *((uint16_t *)(extra + 2));
+		if (currentlyBigEndian())
+			sub_field_len = endianSwapU16(sub_field_len);
 		i = i + 2 + sub_field_len;
 	}
 	delete[] extra;
@@ -1230,6 +1262,10 @@ uint16_t BAMPatternSource::nextBGZFBlockFromFile(BGZF& b) {
                 std::cerr << "Error while reading BAM footer" << std::endl;
                 exit(EXIT_FAILURE);
         }
+	if (currentlyBigEndian()) {
+		b.ftr.crc32 = endianSwapU32(b.ftr.crc32);
+		b.ftr.isize = endianSwapU32(b.ftr.isize);
+	}
 	return bsize;
 }
 
@@ -1302,12 +1338,16 @@ std::pair<bool, int> BAMPatternSource::get_alignments(PerThreadReadBuf& pt, bool
 		EList<Read>& readbuf = pp_.align_paired_reads && !read1 ? pt.bufb_ : pt.bufa_;
 
 		memcpy(&block_size, &bam_batches_[pt.tid_][0] + i, sizeof(block_size));
+		if (currentlyBigEndian())
+			block_size = endianSwapU32(block_size);
 		if (block_size <= 0) {
 			return make_pair(done, readi);
 		}
 		i += sizeof(block_size);
 
 		memcpy(&flag, &bam_batches_[pt.tid_][0] + i + offset[BAMField::flag], sizeof(flag));
+		if (currentlyBigEndian())
+			flag = endianSwapU16(flag);
 		if (!pp_.align_paired_reads && ((flag & 0x40) != 0 || (flag & 0x80) != 0)) {
 			readbuf[readi].readOrigBuf.clear();
 			i += block_size;
@@ -1435,6 +1475,10 @@ bool BAMPatternSource::parse(Read& ra, Read& rb, TReadId rdid) const {
 	memcpy(&l_read_name, buf + offset[BAMField::l_read_name], sizeof(l_read_name));
 	memcpy(&n_cigar_op, buf + offset[BAMField::n_cigar_op], sizeof(n_cigar_op));
 	memcpy(&l_seq, buf + offset[BAMField::l_seq], sizeof(l_seq));
+	if (currentlyBigEndian()) {
+		n_cigar_op = endianSwapU16(n_cigar_op);
+		l_seq = endianSwapU32(l_seq);
+	}
 
 	int off = offset[BAMField::read_name];
 	ra.name.install(buf + off, l_read_name-1);
