@@ -134,6 +134,7 @@ void SamConfig::printAlignedOptFlags(
 	const
 {
 	char buf[1024];
+	bool uniqueAlignment;
 	assert(summ.bestScore(rd.mate < 2).valid());
 	if(print_as_) {
 		// AS:i: Alignment score generated by aligner
@@ -155,7 +156,17 @@ void SamConfig::printAlignedOptFlags(
 			WRITE_SEP();
 			o.append("XS:i:");
 			o.append(buf);
-		}
+		}  else {
+			// If we did not find a secondary alignment for the read and
+			// the average seed hits is less than the max DP failures allowed,
+			// then we conclude that the alignment is unique.
+			int mate = (rd.mate < 2 ? 0 : 1);
+			float seedHitAvgMS = (prm.seedHitAvgMS[2 * mate] + prm.seedHitAvgMS[2 * mate + 1]) + 0.5f;
+                        if (seedHitAvgMS < prm.maxDPFails) {
+				uniqueAlignment = true;
+			}
+                }
+
 	}
 	if(print_xn_) {
 		// XN:i: Number of ambiguous bases in the referenece
@@ -164,6 +175,7 @@ void SamConfig::printAlignedOptFlags(
 		o.append("XN:i:");
 		o.append(buf);
 	}
+
 	if(print_x0_) {
 		// X0:i: Number of best hits
 	}
@@ -664,6 +676,8 @@ void SamConfig::printAlignedOptFlags(
 		o.append(",");
 		itoa10<TAlScore>((int)(prm.seedHitAvgMS[2 * mate + fw] + 0.5f), buf);
 		o.append(buf);
+		if (uniqueAlignment)
+			o.append(",unique alignment");
 	}
 }
 
